// SPDX-License-Identifier: BUSL-1.1
pragma solidity 0.8.21;

import "@openzeppelin/contracts/token/ERC20/utils/SafeERC20.sol";

contract EeseeDrop {
    using SafeERC20 for IERC20;

    struct Recipient {
        address recipient;
        uint256 amount;
    }
    
    error InvalidCaller();

    address owner;

    constructor() {
        owner = msg.sender;
    }

    modifier onlyOwner() {
        if (msg.sender != owner) revert InvalidCaller();
        _;
    }

    /**
     * @dev Drops tokens to recipients.
     * @param token - Token to airdrop.
     * @param recipients - Recipients' addresses and amounts they receive.
     * Note: This function can only be called by AIRDROP_ROLE.
     */
    function drop(IERC20 token, Recipient[] calldata recipients) external onlyOwner {
        for(uint256 i; i < recipients.length;) {
            token.safeTransfer(recipients[i].recipient, recipients[i].amount);
            unchecked { ++i; }
        }
    }
}
